from pyutils_spirit.spirit_container.annotation import component


@component(signature="cities")
class CitiesComponent:

    def __init__(self, get_cities_func: callable, get_provinces_func: callable):
        self.get_cities: callable = get_cities_func
        self.get_provinces: callable = get_provinces_func



from pyutils_spirit.component.components import CitiesComponent

from pyutils_spirit.util.cities import get_provinces, get_cities

CitiesComponent(get_cities_func=get_cities, get_provinces_func=get_provinces)

print("component module initialized")
